@@ -42,9 +42,9 @@ class BadlogModel(Model):
             if "data" not in X.keys():
                 raise ValueError("'data' key is required")
             X_df = pd.DataFrame.from_dict(X["data"])
-            metadata = X["metadata"]
+            self.metadata = X["metadata"]
             self.X_pred, self.num_cols, self.cat_cols = helpers._apply_metadata(
-                X_df, **kwargs.get("_metadata", metadata)
+                X_df, **kwargs.get("_metadata", self.metadata)
             )
         elif isinstance(X, pd.core.frame.DataFrame):
             X_df = X.copy()
@@ -164,7 +164,7 @@ class BadlogModel(Model):
                     self.X_pred, cp_names, datasets, models
                 )
             else:
-                method_flags = method_evaluator(self.X_pred, **kwargs)
+                method_flags = method_evaluator(self.X_pred, **self.metadata, **kwargs)
             self.y[method_flags.columns] = method_flags
         result_columns = [
             col
