@@ -18,8 +18,14 @@ def get_outliers(
     Returns:
         DataFrame: y_pred with added flag columns
     """
+    df_well.loc[:, ["flag_washout_gen", "flag_washout_den"]] = 0, 0
+    if y_pred is None:
+        y_pred = df_well.copy()
+
     if "CALI" in df_well.columns and "BS" in df_well.columns:
         df_well.loc[:, "CALI_BS"] = np.abs(df_well["CALI"] - df_well["BS"])
+    else:
+        return y_pred
 
     x = "CALI_BS"
     y = "CALI_BS"
@@ -36,14 +42,10 @@ def get_outliers(
 
     df_well = BS_helpers.find_BS_jumps(df_well)
 
-    if y_pred is None:
-        y_pred = df_well.copy()
-
     # return if too many BS regions (a couple of wells with non-standard values)
     if df_well["BS_region"].nunique() >= 10:
-        return y_pred
+        return df_well
 
-    y_pred.loc[:, ["flag_washout_gen", "flag_washout_den"]] = 0, 0
     den_washout_anomalies = []
 
     for bsr in df_well["BS_region"].unique():
@@ -80,14 +82,15 @@ def flag_washout(df_well: DataFrame, y_pred: DataFrame = None, **kwargs) -> Data
     if "score_washout_gen" not in y_pred.columns:
         y_pred.loc[:, "score_washout_gen"] = 0
     rolling_window = kwargs.get("washout_rolling_window", 101)
+    if not "BS_region" in y_pred.columns:
+        return y_pred
     for bsr in y_pred["BS_region"].unique():
         df_gr = y_pred[y_pred["BS_region"] == bsr].copy()
         rows_with_values = df_gr[df_gr["CALI"].isna() == False].index
         if len(rows_with_values):
             df_gr.loc[rows_with_values, "CALI_std"] =\
                 df_gr.loc[
-                    rows_with_values, "CALI"
-                ].rolling(rolling_window).std().fillna(0)
+                    rows_with_values, "CALI"].rolling(rolling_window).std().fillna(0)
             y_pred.loc[rows_with_values, "score_washout_gen"] =\
                 np.abs(standardizer(
                     df_gr.loc[rows_with_values, "CALI_std"].values.reshape(-1, 1)
